.. _avocado-ec2-plugin:

==================
Avocado-ec2 Plugin
==================

This plugin allows you to run tests on Amazon EC2 instances.
`Details available here <https://github.com/avocado-framework/avocado-ec2>`__
